@@ -49,6 +49,7 @@ from nwg_panel.modules.dwl_tags import DwlTags
 from nwg_panel.modules.swaync import SwayNC
 from nwg_panel.modules.sway_mode import SwayMode
 from nwg_panel.modules.keyboard_layout import KeyboardLayout
+from nwg_panel.modules.random_wallpaper import RandomWallpaper
 
 try:
     from nwg_panel.modules.openweather import OpenWeather
@@ -166,7 +167,7 @@ def hypr_watcher():
 
     while True:
         datagram = client.recv(2048)
-        e_full_string = datagram.decode('utf-8').strip()
+        e_full_string = datagram.decode('utf-8', errors='replace').strip()
         lines = e_full_string.splitlines()
 
         event_names = []
@@ -295,11 +296,11 @@ def instantiate_content(panel, container, content_list, icons_path=""):
 
         if item == "hyprland-taskbar":
             if "hyprland-taskbar" in panel:
-                if panel["layer"] in ["bottom", "background"]:
-                    eprint(
-                        "Panel '{}': On Hyprland, panels must be placed on 'top' or 'overlay' layer, but '{}' found in "
-                        "settings. Changing to 'top'.".format(panel["name"], panel["layer"]))
-                    panel["layer"] = "top"  # or context menu will remain invisible
+                # if panel["layer"] in ["bottom", "background"]:
+                #     eprint(
+                #         "Panel '{}': On Hyprland, panels must be placed on 'top' or 'overlay' layer, but '{}' found in "
+                #         "settings. Changing to 'top'.".format(panel["name"], panel["layer"]))
+                #     panel["layer"] = "top"  # or context menu will remain invisible
                 if his:
                     check_key(panel["hyprland-taskbar"], "all-outputs", False)
                     if panel["hyprland-taskbar"]["all-outputs"] or "output" not in panel:
@@ -383,6 +384,12 @@ def instantiate_content(panel, container, content_list, icons_path=""):
             cpu_avg = CpuAvg()
             container.pack_start(cpu_avg, False, False, panel["items-padding"])
 
+        if item == "random-wallpaper":
+            if item not in panel:
+                panel[item] = {}
+            cpu_avg = RandomWallpaper(panel[item], voc, icons_path)
+            container.pack_start(cpu_avg, False, False, panel["items-padding"])
+
         if item == "dwl-tags":
             if os.path.isfile(common.dwl_data_file):
                 if "dwl-tags" not in panel:
@@ -704,10 +711,6 @@ def main():
 
             inner_box = Gtk.Box(orientation=o, spacing=0)
 
-            # set equal columns width by default if "modules-center" not empty; this may be overridden in config
-            if panel["modules-center"] and panel["homogeneous"]:
-                inner_box.set_homogeneous(True)
-
             hbox.pack_start(inner_box, True, True, 0)
             hbox.set_property("margin-start", panel["padding-horizontal"])
             hbox.set_property("margin-end", panel["padding-horizontal"])
@@ -744,7 +747,12 @@ def main():
 
             center_box = Gtk.Box(orientation=o, spacing=panel["spacing"])
             center_box.set_property("name", "center-box")
-            inner_box.pack_start(center_box, True, False, 0)
+
+            if panel["modules-center"] and panel["homogeneous"]:
+                inner_box.set_center_widget(center_box)
+            else:
+                inner_box.pack_start(center_box, True, False, 0)
+
             check_key(panel, "modules-center", [])
             instantiate_content(panel, center_box, panel["modules-center"], icons_path=icons_path)
             print("center box created")
@@ -754,7 +762,7 @@ def main():
             # Damn on the guy who invented `pack_start(child, expand, fill, padding)`!
             helper_box = Gtk.Box(orientation=o, spacing=0)
             helper_box.pack_end(right_box, False, False, 0)
-            inner_box.pack_start(helper_box, False, True, 0)
+            inner_box.pack_end(helper_box, False, True, 0)
             check_key(panel, "modules-right", [])
             instantiate_content(panel, right_box, panel["modules-right"], icons_path=icons_path)
             print("right box created")
