@@ -349,6 +349,7 @@ class PopupWindow(Gtk.Window):
             inner_hbox.pack_start(self.bri_image, False, False, 6)
 
             self.bri_scale = Gtk.Scale.new_with_range(orientation=Gtk.Orientation.HORIZONTAL, min=0, max=100, step=1)
+            self.bri_scale.set_increments(0.5, 0.5)
 
             if self.settings["backlight-controller"] == "ddcutil":
                 self.bri_scale_handler = self.bri_scale.connect("value-changed", self.on_value_changed)
@@ -381,6 +382,7 @@ class PopupWindow(Gtk.Window):
             inner_hbox.pack_start(eb, False, False, 6)
 
             self.vol_scale = Gtk.Scale.new_with_range(orientation=Gtk.Orientation.HORIZONTAL, min=0, max=100, step=1)
+            self.vol_scale.set_increments(0.5, 0.5)
             self.vol_scale.set_value(self.parent.vol_value)
             self.vol_scale_handler = self.vol_scale.connect("value-changed", self.set_vol)
 
@@ -592,20 +594,23 @@ class PopupWindow(Gtk.Window):
             for c in self.per_app_vol_box.get_children():
                 c.destroy()
             for inp in sink_inputs:
-                props = sink_inputs[inp]["Properties"]
-                icon_name = props[
-                    "application.icon_name"] if "application.icon_name" in props else "emblem-music-symbolic"
-                vol = 0
-                for p in sink_inputs[inp]["Volume"].split():
-                    if p.endswith("%"):
-                        try:
-                            vol = int(p[:-1])
-                        except:
-                            pass
-                scale = PerAppSlider(inp, vol, icon_name, props["application.name"], props["media.name"])
-                self.per_app_sliders.append(scale)
-                self.per_app_vol_box.pack_start(scale, False, False, 0)
-        self.show_all()
+                props = sink_inputs[inp]["Properties"] if "Properties" in sink_inputs[inp]["Properties"] else {}
+                if props:
+                    icon_name = props[
+                        "application.icon_name"] if "application.icon_name" in props else "emblem-music-symbolic"
+                    vol = 0
+                    if "Volume" in sink_inputs[inp]:
+                        for p in sink_inputs[inp]["Volume"].split():
+                            if p.endswith("%"):
+                                try:
+                                    vol = int(p[:-1])
+                                except:
+                                    pass
+                        if "application.name" in props and "media.name" in props:
+                            scale = PerAppSlider(inp, vol, icon_name, props["application.name"], props["media.name"])
+                            self.per_app_sliders.append(scale)
+                            self.per_app_vol_box.pack_start(scale, False, False, 0)
+                            self.show_all()
 
     def switch_menu_box(self, widget, event):
         if self.menu_box.get_visible():
@@ -681,32 +686,36 @@ class PopupWindow(Gtk.Window):
                 for inp in sink_inputs:
                     if inp not in already_have_slider:
                         # We have no slider for input {inp}. Let's add it.
-                        props = sink_inputs[inp]["Properties"]
-                        icon_name = props[
-                            "application.icon_name"] if "application.icon_name" in props else "emblem-music-symbolic"
-                        vol = 0
-                        for p in sink_inputs[inp]["Volume"].split():
-                            if p.endswith("%"):
-                                try:
-                                    vol = int(p[:-1])
-                                except:
-                                    pass
-                        scale = PerAppSlider(inp, vol, icon_name, props["application.name"], props["media.name"])
-                        self.per_app_sliders.append(scale)
-                        self.per_app_vol_box.pack_start(scale, False, False, 0)
-                        scale.show_all()
+                        props = sink_inputs[inp]["Properties"] if "Properties" in sink_inputs[inp] else {}
+                        if props:
+                            icon_name = props[
+                                "application.icon_name"] if "application.icon_name" in props else "emblem-music-symbolic"
+                            vol = 0
+                            if "Volume" in sink_inputs[inp]:
+                                for p in sink_inputs[inp]["Volume"].split():
+                                    if p.endswith("%"):
+                                        try:
+                                            vol = int(p[:-1])
+                                        except:
+                                            pass
+                                if "application.name" in props and "media.name" in props:
+                                    scale = PerAppSlider(inp, vol, icon_name, props["application.name"],
+                                                         props["media.name"])
+                                    self.per_app_sliders.append(scale)
+                                    self.per_app_vol_box.pack_start(scale, False, False, 0)
+                                    scale.show_all()
 
-                    vol = 0
-                    for p in sink_inputs[inp]["Volume"].split():
-                        if p.endswith("%"):
-                            try:
-                                vol = int(p[:-1])
-                            except:
-                                pass
+                                vol = 0
+                                for p in sink_inputs[inp]["Volume"].split():
+                                    if p.endswith("%"):
+                                        try:
+                                            vol = int(p[:-1])
+                                        except:
+                                            pass
 
-                    for sc in self.per_app_sliders:
-                        if sc.input_num == inp:
-                            sc.scale.set_value(vol)
+                                for sc in self.per_app_sliders:
+                                    if sc.input_num == inp:
+                                        sc.scale.set_value(vol)
 
                 # In case the app is closed while popup still open
                 for sc in self.per_app_sliders:
@@ -804,6 +813,7 @@ class PerAppSlider(Gtk.Box):
         lbl.set_markup('<span size="small">{}</span>'.format(name))
         vbox.pack_start(lbl, False, False, 0)
         self.scale = Gtk.Scale.new_with_range(orientation=Gtk.Orientation.HORIZONTAL, min=0, max=153, step=1)
+        self.scale.set_increments(0.5, 0.5)
         self.scale.connect("value-changed", self.set_volume)
         self.scale.set_value(volume)
         self.scale.set_draw_value(False)
